#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.reference import Reference
from pycatia.in_interfaces.references import References
from pycatia.knowledge_interfaces.length import Length
from pycatia.part_interfaces.dress_up_shape import DressUpShape


class AutoFillet(DressUpShape):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.Shape
                |                         PartInterfaces.DressUpShape
                |                             AutoFillet
                | 
                | Represents the AutoFillet shape.
                | A AutoFillet fillets all the edges of Solid

    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.auto_fillet = com_object

    @property
    def curvature_radius(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property CurvatureRadius() As Length (Read Only)
                | 
                |     Returns the Curvature radius.
                | 
                |     Example:
                |         The following example returns in Curvature radius the Curvature radius
                |         of the AutoFillet Autofillet:
                | 
                |          Set Curvatureradius = Autofillet.Radius

        :rtype: Length
        """

        return Length(self.auto_fillet.CurvatureRadius)

    @property
    def faces_to_fillet(self) -> References:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property FacesToFillet() As References (Read Only)
                | 
                |     Returns or sets the faces to fillet.
                | 
                |     Example:
                |         The following example returns in facestofillet the faces required for
                |         autofillet autoFillet, and then sets it to
                |         NewFacestofillet:
                | 
                |          Set Facestofillet = autoFillet.Facestofillet
                |          autofillet.Facestofillet = NewFacestofillet

        :rtype: References
        """

        return References(self.auto_fillet.FacesToFillet)

    @property
    def faces_to_fillets(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property FacesToFillets(Reference iFace) (Write Only)

        :rtype: Reference
        """

        return self.auto_fillet.FacesToFillets

    @faces_to_fillets.setter
    def faces_to_fillets(self, reference: Reference):
        """
        :param Reference reference:
        """

        self.auto_fillet.FacesToFillets = reference.com_object

    @property
    def fillet_radius(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property FilletRadius() As Length (Read Only)
                | 
                |     Returns the Fillet radius.
                | 
                |     Example:
                |         The following example returns in fillet radius the fillet radius of the
                |         AutoFillet Autofillet:
                | 
                |          Set Filletradius = Autofillet.Radius

        :rtype: Length
        """

        return Length(self.auto_fillet.FilletRadius)

    @property
    def functional_face(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property FunctionalFace(Reference iFace) (Write Only)

        :rtype: Reference
        """

        return Reference(self.auto_fillet.FunctionalFace)

    @functional_face.setter
    def functional_face(self, reference: Reference):
        """
        :param Reference reference:
        """

        self.auto_fillet.FunctionalFace = reference.com_object

    @property
    def functional_faces(self) -> References:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property FunctionalFaces() As References (Read Only)
                | 
                |     Returns or sets the functional face.
                | 
                |     Example:
                |         The following example returns in functionalface the functional face of
                |         the autofillet autoFillet, and then sets it to
                |         NewfunctionalFace:
                | 
                |          Set functionalFace = autoFillet.FunctionalFace
                |          autofillet.FunctionalFace = NewfunctionalFace

        :rtype: References
        """

        return References(self.auto_fillet.FunctionalFaces)

    @property
    def parting_element(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property PartingElement() As Reference
                | 
                |     Returns or sets the parting element.
                | 
                |     Example:
                |         The following example returns in partingelement the parting element of
                |         the autofillet autoFillet, and then sets it to Newparting
                |         element:
                | 
                |          Set Parting element = autoFillet.PartingElement
                |          autofillet.PartingElement = NewPartingElement

        :rtype: Reference
        """

        return Reference(self.auto_fillet.PartingElement)

    @parting_element.setter
    def parting_element(self, reference: Reference):
        """
        :param Reference reference:
        """

        self.auto_fillet.PartingElement = reference.com_object

    @property
    def round_radius(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property RoundRadius() As Length (Read Only)
                | 
                |     Returns the Round radius.
                | 
                |     Example:
                |         The following example returns in round radius the round radius of the
                |         AutoFillet Autofillet:
                | 
                |          Set roundradius = Autofillet.Radius

        :rtype: Length
        """

        return Length(self.auto_fillet.RoundRadius)

    @property
    def round_radius_activation(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property RoundRadiusActivation() As boolean
                | 
                |     Returns the AutoFillet RoundRadiusActivation flag (for AutoFillet
                |     only).
                |     It returns 1 if RoundRadius is activated, 0 if not.
                | 
                |     Returns:
                |         oRoundRadActivation The RoundRadActivation flag as an
                |         int
                | 
                |         Example:

        :rtype: bool
        """

        return self.auto_fillet.RoundRadiusActivation

    @round_radius_activation.setter
    def round_radius_activation(self, value: bool):
        """
        :param bool value:
        """

        self.auto_fillet.RoundRadiusActivation = value

    @property
    def slivers_and_crack(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SliversAndCrack(Reference iSlivers) (Write Only)

        :rtype: Reference
        """

        return self.auto_fillet.SliversAndCrack

    @slivers_and_crack.setter
    def slivers_and_crack(self, reference: Reference):
        """
        :param Reference reference:
        """

        self.auto_fillet.SliversAndCrack = reference.com_object

    @property
    def slivers_and_cracks(self) -> References:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SliversAndCracks() As References (Read Only)
                | 
                |     Returns or sets the slivers face.
                | 
                |     Example:
                |         The following example returns in slivers the sliver face of the
                |         autofillet autoFillet, and then sets it to Newsliver:
                | 
                |          Set sliversFace = autoFillet.SliversFace
                |          autofillet.SliversFace = NewsliversFace

        :rtype: References
        """

        return References(self.auto_fillet.SliversAndCracks)

    @property
    def support_surface(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property SupportSurface() As Reference
                | 
                |     Returns or sets the support surface.
                | 
                |     Example:
                |         The following example returns in SupportSurface the support surface
                |         required for autofillet autoFillet, and then sets it to
                |         NewSupportSurface:
                | 
                |          Set SupportSurface = autoFillet.SupportSurface
                |          autofillet.SupportSurface = NewSupportSurface

        :rtype: Reference
        """

        return Reference(self.auto_fillet.SupportSurface)

    @support_surface.setter
    def support_surface(self, reference: Reference):
        """
        :param Reference reference:
        """

        self.auto_fillet.SupportSurface = reference.com_object

    def __repr__(self):
        return f'AutoFillet(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.document import Document
from pycatia.product_structure_interfaces.product import Product
from pycatia.simulation_interfaces.replay import Replay
from pycatia.smt_interfaces.swept_volume import SweptVolume
from pycatia.system_interfaces.any_object import AnyObject
from pycatia.system_interfaces.collection import Collection


class SweptVolumes(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     SweptVolumes
                | 
                | Interface to compute swept volumes.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=SweptVolume)
        self.swept_volumes = com_object

    def add(
            self,
            replay: Replay,
            i_products_to_swept: tuple,
            i_product_reference: Product,
            i_lod_mode: int,
            i_accuracy: float,
            i_shape_name: str,
            i_activated_shape: int,
            i_default_shape: int
    ) -> SweptVolume:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Add(Replay replay,
                | CATSafeArrayVariant iProductsToSwept,
                | Product iProductReference,
                | long iLODMode,
                | double iAccuracy,
                | CATBSTR iShapeName,
                | long iActivatedShape,
                | long iDefaultShape) As SweptVolume
                | 
                |     Creates a new SweptVolume and adds it to the SweptVolumes collection. This
                |     function is deprecated.
                | 
                |     Returns:
                |         The created SweptVolume 
                |     Example:
                |         The following example creates a SweptVolume newSweptVolume in the
                |         SweptVolume collection.
                | 
                |          Set SweptVolume = SweptVolumes.Add

        :param Replay replay:
        :param tuple i_products_to_swept:
        :param Product i_product_reference:
        :param int i_lod_mode:
        :param float i_accuracy:
        :param str i_shape_name:
        :param int i_activated_shape:
        :param int i_default_shape:
        :rtype: SweptVolume
        """
        return SweptVolume(
            self.swept_volumes.Add(
                replay.com_object,
                i_products_to_swept,
                i_product_reference.com_object,
                i_lod_mode,
                i_accuracy,
                i_shape_name,
                i_activated_shape,
                i_default_shape
            )
        )

    def add_from_swept_able(
            self,
            i_swept_able: AnyObject,
            i_products_to_swept: tuple,
            i_product_reference: Product,
            i_lod_mode: int,
            i_accuracy: float,
            i_shape_name: str,
            i_activated_shape: int,
            i_default_shape: int
    ) -> SweptVolume:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddFromSweptAble(CATBaseDispatch iSweptAble,
                | CATSafeArrayVariant iProductsToSwept,
                | Product iProductReference,
                | long iLODMode,
                | double iAccuracy,
                | CATBSTR iShapeName,
                | long iActivatedShape,
                | long iDefaultShape) As SweptVolume
                | 
                |     Creates a new SweptVolume and adds it to the SweptVolumes collection. This
                |     function is deprecated.
                | 
                |     Returns:
                |         The created SweptVolume

        :param AnyObject i_swept_able:
        :param tuple i_products_to_swept:
        :param Product i_product_reference:
        :param int i_lod_mode:
        :param float i_accuracy:
        :param str i_shape_name:
        :param int i_activated_shape:
        :param int i_default_shape:
        :rtype: SweptVolume
        """
        return SweptVolume(
            self.swept_volumes.AddFromSweptAble(
                i_swept_able.com_object,
                i_products_to_swept,
                i_product_reference.com_object,
                i_lod_mode,
                i_accuracy,
                i_shape_name,
                i_activated_shape,
                i_default_shape
            )
        )

    def clean_up(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub CleanUp()
                | 
                |     Cleans up.

        :rtype: None
        """
        return self.swept_volumes.CleanUp()

    def compute_a_swept_volume(
            self,
            i_replay: Replay,
            i_swept_able: AnyObject,
            i_products_to_swept: tuple,
            i_product_reference: Product,
            i_lod_mode: int,
            i_accuracy: float,
            i_wrapping_grain: float,
            i_wrapping_ratio: float,
            i_simplify_accuracy: float
    ) -> Document:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ComputeASweptVolume(Replay iReplay,
                | CATBaseDispatch iSweptAble,
                | CATSafeArrayVariant iProductsToSwept,
                | Product iProductReference,
                | long iLODMode,
                | double iAccuracy,
                | double iWrappingGrain,
                | double iWrappingRatio,
                | double iSimplifAccuracy) As Document
                | 
                |     Computes a swept volume. This function is deprecated.
                | 
                |     Returns:
                |         The created SweptVolume

        :param Replay i_replay:
        :param AnyObject i_swept_able:
        :param tuple i_products_to_swept:
        :param Product i_product_reference:
        :param int i_lod_mode:
        :param float i_accuracy:
        :param float i_wrapping_grain:
        :param float i_wrapping_ratio:
        :param float i_simplify_accuracy:
        :rtype: Document
        """
        return Document(
            self.swept_volumes.ComputeASweptVolume(
                i_replay.com_object,
                i_swept_able.com_object,
                i_products_to_swept,
                i_product_reference.com_object,
                i_lod_mode,
                i_accuracy,
                i_wrapping_grain,
                i_wrapping_ratio,
                i_simplify_accuracy
            )
        )

    def compute_a_swept_volume_from_replay(
            self,
            i_replay: Replay,
            i_products_to_swept: tuple,
            i_product_reference: Product,
            i_lod_mode: int,
            i_accuracy: float,
            i_wrapping_grain: float,
            i_wrapping_ratio: float,
            i_simplif_accuracy: float
    ) -> Document:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ComputeASweptVolumeFromReplay(Replay iReplay,
                | CATSafeArrayVariant iProductsToSwept,
                | Product iProductReference,
                | long iLODMode,
                | double iAccuracy,
                | double iWrappingGrain,
                | double iWrappingRatio,
                | double iSimplifAccuracy) As Document
                | 
                |     Computes a swept volume. This function is deprecated.
                | 
                |     Returns:
                |         The created SweptVolume

        :param Replay i_replay:
        :param tuple i_products_to_swept:
        :param Product i_product_reference:
        :param int i_lod_mode:
        :param float i_accuracy:
        :param float i_wrapping_grain:
        :param float i_wrapping_ratio:
        :param float i_simplif_accuracy:
        :rtype: Document
        """
        return Document(
            self.swept_volumes.ComputeASweptVolumeFromReplay(
                i_replay.com_object,
                i_products_to_swept,
                i_product_reference.com_object,
                i_lod_mode,
                i_accuracy,
                i_wrapping_grain,
                i_wrapping_ratio,
                i_simplif_accuracy
            )
        )

    def compute_a_swept_volume_from_sweptable(
            self,
            i_swept_able: AnyObject,
            i_products_to_swept: tuple,
            i_product_reference: Product,
            i_lod_mode: int,
            i_accuracy: float,
            i_wrapping_grain: float,
            i_wrapping_ratio: float,
            i_simplify_accuracy: float
    ) -> Document:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ComputeASweptVolumeFromSweptable(CATBaseDispatch
                | iSweptAble,
                | CATSafeArrayVariant iProductsToSwept,
                | Product iProductReference,
                | long iLODMode,
                | double iAccuracy,
                | double iWrappingGrain,
                | double iWrappingRatio,
                | double iSimplifAccuracy) As Document
                | 
                |     Computes a swept volume. This function is deprecated.
                | 
                |     Returns:
                |         The created SweptVolume

        :param AnyObject i_swept_able:
        :param tuple i_products_to_swept:
        :param Product i_product_reference:
        :param int i_lod_mode:
        :param float i_accuracy:
        :param float i_wrapping_grain:
        :param float i_wrapping_ratio:
        :param float i_simplify_accuracy:
        :rtype: Document
        """
        return Document(
            self.swept_volumes.ComputeASweptVolumeFromSweptable(
                i_swept_able.com_object,
                i_products_to_swept,
                i_product_reference.com_object,
                i_lod_mode,
                i_accuracy,
                i_wrapping_grain,
                i_wrapping_ratio,
                i_simplify_accuracy
            )
        )

    def compute_swept_volumes(
            self,
            i_replay: Replay,
            i_swept_able: AnyObject,
            i_products_to_swept: tuple,
            i_product_reference: Product,
            i_lod_mode: int,
            i_accuracy: float,
            i_perform_wrapping: int,
            i_perform_simplif: int,
            i_wrapping_grain: float,
            i_wrapping_ratio: float,
            i_simplify_accuracy: float,
            o_swept_volume_documents: tuple
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ComputeSweptVolumes(Replay iReplay,
                | CATBaseDispatch iSweptAble,
                | CATSafeArrayVariant iProductsToSwept,
                | Product iProductReference,
                | long iLODMode,
                | double iAccuracy,
                | long iPerformWrapping,
                | long iPerformSimplif,
                | double iWrappingGrain,
                | double iWrappingRatio,
                | double iSimplifAccuracy,
                | CATSafeArrayVariant oSweptVolumeDocuments)
                | 
                |     Computes a swept volume, from a replay or a track.
                | 
                |     Parameters:
                | 
                |         iReplay
                |             Replay on which we perfom the swept volume. Can be NULL.
                |             
                |         iSweptAble
                |             Track (or any other thing that implements CATISweptAble) on which
                |             we perfom the swept volume. Can be NULL. 
                |         iProductsToSwept
                |             Selection of products to sweep. 
                |         iProductReference
                |             Product taken as a reference. 
                |         iLODMode
                |             Do we want levels of details or not? 
                |         iAccuracy
                |             Filtering positions parameter. 
                |         iPerformWrapping
                |             Do we perform a wrapping? 
                |         iPerformSimplif
                |             Do we perform a simplification? 
                |         iWrappingGrain
                |             Grain for wrapping. 
                |         iWrappingRatio
                |             Offset ratio for wrapping. 
                |         iSimplifAccuracy
                |             Accuracy for simplification. 
                | 
                |     Returns:
                |         oSweptVolumeDocuments: Documents containing the results.

        :param Replay i_replay:
        :param AnyObject i_swept_able:
        :param tuple i_products_to_swept:
        :param Product i_product_reference:
        :param int i_lod_mode:
        :param float i_accuracy:
        :param int i_perform_wrapping:
        :param int i_perform_simplify:
        :param float i_wrapping_grain:
        :param float i_wrapping_ratio:
        :param float i_simplif_accuracy:
        :param tuple o_swept_volume_documents:
        :rtype: None
        """
        return self.swept_volumes.ComputeSweptVolumes(
            i_replay.com_object,
            i_swept_able.com_object,
            i_products_to_swept,
            i_product_reference.com_object,
            i_lod_mode,
            i_accuracy,
            i_perform_wrapping,
            i_perform_simplif,
            i_wrapping_grain,
            i_wrapping_ratio,
            i_simplify_accuracy,
            o_swept_volume_documents
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'compute_swept_volumes'
        # # vba_code = """
        # # Public Function compute_swept_volumes(swept_volumes)
        # #     Dim iReplay (2)
        # #     swept_volumes.ComputeSweptVolumes iReplay
        # #     compute_swept_volumes = iReplay
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def compute_swept_volumes_from_replay(
            self,
            i_replay: Replay,
            i_products_to_swept: tuple,
            i_product_reference: Product,
            i_lod_mode: int,
            i_accuracy: float,
            i_perform_wrapping: int,
            i_perform_simplify: int,
            i_wrapping_grain: float,
            i_wrapping_ratio: float,
            i_simplif_accuracy: float,
            o_swept_volume_documents: tuple
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ComputeSweptVolumesFromReplay(Replay iReplay,
                | CATSafeArrayVariant iProductsToSwept,
                | Product iProductReference,
                | long iLODMode,
                | double iAccuracy,
                | long iPerformWrapping,
                | long iPerformSimplif,
                | double iWrappingGrain,
                | double iWrappingRatio,
                | double iSimplifAccuracy,
                | CATSafeArrayVariant oSweptVolumeDocuments)
                | 
                |     Computes a swept volume from a replay.
                | 
                |     Parameters:
                | 
                |         iReplay
                |             Replay on which we perfom the swept volume. 
                |         iProductsToSwept
                |             Selection of products to sweep. 
                |         iProductReference
                |             Product taken as a reference. 
                |         iLODMode
                |             Do we want levels of details or not? 
                |         iAccuracy
                |             Filtering positions parameter. 
                |         iPerformWrapping
                |             Do we perform a wrapping? 
                |         iPerformSimplif
                |             Do we perform a simplification? 
                |         iWrappingGrain
                |             Grain for wrapping. 
                |         iWrappingRatio
                |             Offset ratio for wrapping. 
                |         iSimplifAccuracy
                |             Accuracy for simplification. 
                | 
                |     Returns:
                |         oSweptVolumeDocuments: Documents containing the results.

        :param Replay i_replay:
        :param tuple i_products_to_swept:
        :param Product i_product_reference:
        :param int i_lod_mode:
        :param float i_accuracy:
        :param int i_perform_wrapping:
        :param int i_perform_simplify:
        :param float i_wrapping_grain:
        :param float i_wrapping_ratio:
        :param float i_simplif_accuracy:
        :param tuple o_swept_volume_documents:
        :rtype: None
        """
        return self.swept_volumes.ComputeSweptVolumesFromReplay(
            i_replay.com_object,
            i_products_to_swept,
            i_product_reference.com_object,
            i_lod_mode,
            i_accuracy,
            i_perform_wrapping,
            i_perform_simplify,
            i_wrapping_grain,
            i_wrapping_ratio,
            i_simplif_accuracy,
            o_swept_volume_documents
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'compute_swept_volumes_from_replay'
        # # vba_code = """
        # # Public Function compute_swept_volumes_from_replay(swept_volumes)
        # #     Dim iReplay (2)
        # #     swept_volumes.ComputeSweptVolumesFromReplay iReplay
        # #     compute_swept_volumes_from_replay = iReplay
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def compute_swept_volumes_from_sweptable(
            self,
            i_swept_able: AnyObject,
            i_products_to_swept: tuple,
            i_product_reference: Product,
            i_lod_mode: int,
            i_accuracy: float,
            i_perform_wrapping: int,
            i_perform_simplify: int,
            i_wrapping_grain: float,
            i_wrapping_ratio: float,
            i_simplify_accuracy: float,
            o_swept_volume_documents: tuple
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ComputeSweptVolumesFromSweptable(CATBaseDispatch
                | iSweptAble,
                | CATSafeArrayVariant iProductsToSwept,
                | Product iProductReference,
                | long iLODMode,
                | double iAccuracy,
                | long iPerformWrapping,
                | long iPerformSimplif,
                | double iWrappingGrain,
                | double iWrappingRatio,
                | double iSimplifAccuracy,
                | CATSafeArrayVariant oSweptVolumeDocuments)
                | 
                |     Computes a swept volume from a track.
                | 
                |     Parameters:
                | 
                |         iSweptAble
                |             Track (or any other thing that implements CATISweptAble) on which
                |             we perfom the swept volume. 
                |         iProductsToSwept
                |             Selection of products to sweep. 
                |         iProductReference
                |             Product taken as a reference. 
                |         iLODMode
                |             Do we want levels of details or not? 
                |         iAccuracy
                |             Filtering positions parameter. 
                |         iPerformWrapping
                |             Do we perform a wrapping? 
                |         iPerformSimplif
                |             Do we perform a simplification? 
                |         iWrappingGrain
                |             Grain for wrapping. 
                |         iWrappingRatio
                |             Offset ratio for wrapping. 
                |         iSimplifAccuracy
                |             Accuracy for simplification. 
                | 
                |     Returns:
                |         oSweptVolumeDocuments: Documents containing the results.

        :param AnyObject i_swept_able:
        :param tuple i_products_to_swept:
        :param Product i_product_reference:
        :param int i_lod_mode:
        :param float i_accuracy:
        :param int i_perform_wrapping:
        :param int i_perform_simplify:
        :param float i_wrapping_grain:
        :param float i_wrapping_ratio:
        :param float i_simplify_accuracy:
        :param tuple o_swept_volume_documents:
        :rtype: None
        """
        return self.swept_volumes.ComputeSweptVolumesFromSweptable(
            i_swept_able.com_object,
            i_products_to_swept,
            i_product_reference.com_object,
            i_lod_mode,
            i_accuracy,
            i_perform_wrapping,
            i_perform_simplify,
            i_wrapping_grain,
            i_wrapping_ratio,
            i_simplify_accuracy,
            o_swept_volume_documents
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'compute_swept_volumes_from_sweptable'
        # # vba_code = """
        # # Public Function compute_swept_volumes_from_sweptable(swept_volumes)
        # #     Dim iSweptAble (2)
        # #     swept_volumes.ComputeSweptVolumesFromSweptable iSweptAble
        # #     compute_swept_volumes_from_sweptable = iSweptAble
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_silhouette(self, on_off: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetSilhouette(long OnOff)
                | 
                |     Adds the possibility to make a silhouette before the swept volume

        :param int on_off:
        :rtype: None
        """
        return self.swept_volumes.SetSilhouette(on_off)

    def set_spatial_split(self, on_off: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetSpatialSplit(long OnOff)
                | 
                |     Adds the possibility to parallelize swept&wrapping after a spatial split.
                |     This gains in memory but not in CPU usage (takes longer.)

        :param int on_off:
        :rtype: None
        """
        return self.swept_volumes.SetSpatialSplit(on_off)

    def __repr__(self):
        return f'SweptVolumes(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.analysis_interfaces.analysis_case import AnalysisCase
from pycatia.in_interfaces.folder import Folder
from pycatia.system_interfaces.any_object import AnyObject
from pycatia.types.general import cat_variant


class AnalysisPostManager(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     AnalysisPostManager
                | 
                | Interface to define the Post Processing Manager.
                | Role: In the analysis document, an Post Processing is dedicated to
                | Visualization and reporting.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.analysis_post_manager = com_object

    def add_existing_case_for_report(self, i_case: AnalysisCase) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddExistingCaseForReport(AnalysisCase iCase)
                | 
                |     Adds an existing analysis case to manager. To declare Case which will be
                |     taken into account for the HTML report.
                | 
                |     Parameters:
                | 
                |         iCase
                |             The Existing Analysis Case.

        :param AnalysisCase i_case:
        :rtype: None
        """
        return self.analysis_post_manager.AddExistingCaseForReport(i_case.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_existing_case_for_report'
        # # vba_code = """
        # # Public Function add_existing_case_for_report(analysis_post_manager)
        # #     Dim iCase (2)
        # #     analysis_post_manager.AddExistingCaseForReport iCase
        # #     add_existing_case_for_report = iCase
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def build_report(self, i_folder: Folder, i_title: str, i_add_created_images: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub BuildReport(Folder iFolder,
                | CATBSTR iTitle,
                | CATVariant iAddCreatedImages)
                | 
                |     Extract the HTML Report. The Report is defined related to Analysis cases,
                |     using AddExistingCaseForReport and will be stored in a CATIA
                |     Folder.
                | 
                |     Parameters:
                | 
                |         iFolder
                |             Folder to store the HTML file. 
                |         iTitle
                |             Title of the report. 
                |         iAddCreatedImages
                |             To add created images under analysis case in the
                |             report.

        :param Folder i_folder:
        :param str i_title:
        :param cat_variant i_add_created_images:
        :rtype: None
        """
        return self.analysis_post_manager.BuildReport(i_folder.com_object, i_title, i_add_created_images)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'build_report'
        # # vba_code = """
        # # Public Function build_report(analysis_post_manager)
        # #     Dim iFolder (2)
        # #     analysis_post_manager.BuildReport iFolder
        # #     build_report = iFolder
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def extract_html_report(self, i_folder: Folder, i_title: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ExtractHTMLReport(Folder iFolder,
                | CATBSTR iTitle)
                | 
                |     Deprecated:
                |         V5R14 use BuildReport instead. Extract the HTML Report. The Report is
                |         defined related to Analysis cases, using AddExistingCaseForReport and will be
                |         stored in a CATIA Folder. 
                |     Parameters:
                | 
                |         iFolder
                |             Folder to store the HTML file. 
                |         iTitle
                |             Title of the report.

        :param Folder i_folder:
        :param str i_title:
        :rtype: None
        """
        return self.analysis_post_manager.ExtractHTMLReport(i_folder.com_object, i_title)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'extract_html_report'
        # # vba_code = """
        # # Public Function extract_html_report(analysis_post_manager)
        # #     Dim iFolder (2)
        # #     analysis_post_manager.ExtractHTMLReport iFolder
        # #     extract_html_report = iFolder
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'AnalysisPostManager(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.reference import Reference
from pycatia.knowledge_interfaces.real_param import RealParam
from pycatia.mec_mod_interfaces.shape import Shape


class Scaling2(Shape):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.Shape
                |                         Scaling2
                | 
                | Represents the Scaling2 feature object.
                | This solid feature is created from an underlying HybridShapeScaling aggregated
                | by the Scaling. Role: To access the data of the feature object. This data
                | includes:
                | 
                |     The element to be transformed using the Scaling2
                |     The reference element for the Scaling2 which is a point or a
                |     plane
                |     The ratio and its value
                | 
                | Use the CATIAShapeFactory to create Part object.
                | 
                | See also:
                |     ShapeFactory
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.scaling2 = com_object

    @property
    def center(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Center() As Reference
                | 
                |     Returns or sets the reference element.This element can be a point or a
                |     plane.
                |     To set the property, you can use one of the following Boundary objects:
                |     PlanarFace or Vertex.
                | 
                |     Example:
                |         This example retrieves in RefElem the reference element for the
                |         Scaling2 hybrid shape feature.
                | 
                |          Dim RefElem As Reference
                |          Set RefElem = Scaling2.Center

        :rtype: Reference
        """

        return Reference(self.scaling2.Center)

    @center.setter
    def center(self, value: Reference):
        """
        :param Reference value:
        """

        self.scaling2.Center = value.com_object

    @property
    def ratio(self) -> RealParam:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Ratio() As RealParam (Read Only)
                | 
                |     Returns the scaling ratio.

        :rtype: RealParam
        """

        return RealParam(self.scaling2.Ratio)

    @property
    def ratio_value(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property RatioValue() As double
                | 
                |     Returns or sets the scaling ratio value.
                | 
                |     Example:
                |         This example retrieves in Value the ratio value for the Scaling hybrid
                |         shape feature.
                | 
                |          Dim Value As double
                |          Set Value = Scaling2.RatioValue

        :rtype: float
        """

        return self.scaling2.RatioValue

    @ratio_value.setter
    def ratio_value(self, value: float):
        """
        :param float value:
        """

        self.scaling2.RatioValue = value

    def __repr__(self):
        return f'Scaling2(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dmaps_interfaces.activity import Activity
from pycatia.dnb_state_interfaces.dnb_3d_state import DNB3DState
from pycatia.dnb_state_interfaces.dnb_3d_states import DNB3DStates
from pycatia.system_interfaces.any_object import AnyObject


class DNB3DStateManagement(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     DNB3DStateManagement
                | 
                | Interface representing the 3D State Management in the
                | CATDocument.
                | 
                | Role: Provides access the C++ interfaces DNBIState, DNBIStateMgt to create and
                | manage the 3D States.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.dnb_3d_state_management = com_object

    def create_3d_state(self, i_state_name: str, i_object: AnyObject, i_list_defn: tuple) -> DNB3DState:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Create3DState(CATBSTR iStateName,
                | CATBaseDispatch iObject,
                | CATSafeArrayVariant iListDefn) As DNB3DState
                | 
                |     Creates a 3D State object
                | 
                |     Parameters:
                | 
                |         iStateName
                |             The name of the 3D State to be created. 
                |         iObject
                |             The object(Resource/MA/Product..)on which the state is to be
                |             created 
                |         iListDefn
                |             The definition list(an existing 3D State/3D Position) on which the
                |             new state is to be created 
                | 
                |     Returns:
                |         oState The 3D State object created.
                | 
                |         Example:
                |             For example, Creating a 3D State with the name "My NewState" on the
                |             already existing 3D State "My State".
                | 
                |              Dim MySelectedProduct
                |              Dim MySelectedState as DNB3DState
                |              Dim MyNewState1 as DNB3DState
                |              defnArray[0] = MySelectedState
                |              Set MyNewState1 = stateManagement.Create3DState("My NewState",MySelectedProduct,defnArray)

        :param str i_state_name:
        :param AnyObject i_object:
        :param tuple i_list_defn:
        :rtype: DNB3DState
        """
        return DNB3DState(self.dnb_3d_state_management.Create3DState(i_state_name, i_object.com_object, i_list_defn))

    def delete_3d_state(self, i_state: DNB3DState) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Delete3DState(DNB3DState iState)
                | 
                |     Deletes the specified state object
                | 
                |     Parameters:
                | 
                |         iState
                |             The 3D State object to be deleted.
                | 
                |             Example:
                | 
                |                  Dim MySelectedProduct
                |                  Dim MySelectedState as DNB3DState
                |                 
                |                 stateManagement.Delete3DState(MySelectedState)

        :param DNB3DState i_state:
        :rtype: None
        """
        return self.dnb_3d_state_management.Delete3DState(i_state.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'delete3_d_state'
        # # vba_code = """
        # # Public Function delete3_d_state(dnb3_d_state_management)
        # #     Dim iState (2)
        # #     dnb3_d_state_management.Delete3DState iState
        # #     delete3_d_state = iState
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_3d_state(self, i_object: AnyObject, i_state_name: str) -> DNB3DState:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Get3DState(CATBaseDispatch iObject,
                | CATBSTR iStateName) As DNB3DState
                | 
                |     Returns the 3D State object given its name and the
                |     object(Resource/MA/Product..) on which the state is
                |     created.
                | 
                |     Parameters:
                | 
                |         iObject
                |             The object(Resource/MA/Product..), on which the state is created.
                |             
                |         iStateName
                |             The name of the 3D State. 
                | 
                |     Returns:
                |         oState The 3D States object.
                | 
                |         Example:
                | 
                |              Dim MySelectedProduct
                |              Dim state as DNB3DState
                |              Set state = stateManagement.GetState(MySelectedProduct, "My State1")

        :param AnyObject i_object:
        :param str i_state_name:
        :rtype: DNB3DState
        """
        return DNB3DState(self.dnb_3d_state_management.Get3DState(i_object.com_object, i_state_name))

    def get_number_of_3d_states(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetNumberOf3DStates() As long
                | 
                |     Returns the number of 3D State objects in the process
                |     document
                | 
                |     Returns:
                |         numberOfStates The number of 3D States in the current
                |         document.
                | 
                |         Example:
                | 
                |              stateCount = stateManagement.GetNumberOf3DStates

        :rtype: int
        """
        return self.dnb_3d_state_management.GetNumberOf3DStates()

    def get_number_of_3d_states_on_object(self, i_obj: AnyObject) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetNumberOf3DStatesOnObject(CATBaseDispatch iObj) As
                | long
                | 
                |     Returns the number of 3D State objects on a given
                |     object(Resource/MA/Product..)
                | 
                |     Parameters:
                | 
                |         iObject
                |             The object(Resource/MA/Product..), whose states are to be listed.
                | 
                |     Returns:
                |         numberOfStates The number of 3D States created on
                |         iObjec.
                | 
                |         Example:
                | 
                |              stateCount = stateManagement.GetNumberOf3DStatesOnObject(MySelectedProduct)

        :param AnyObject i_obj:
        :rtype: int
        """
        return self.dnb_3d_state_management.GetNumberOf3DStatesOnObject(i_obj.com_object)

    def get_number_of_3d_states_in_activity(self, i_process: Activity, i_condition_type: str) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetNumberof3DStatesInActivity(Activity iProcess,
                | CATBSTR iConditionType) As long
                | 
                |     Returns the number of 3D states assigned to the given activity, based on
                |     the condition on which the activity has been assigned to the 3D
                |     state.
                | 
                |     Parameters:
                | 
                |         iProcess
                |             The activity whose states are to be listed. 
                |         iConditionType
                |             The type of assignment that has been made i.e., the condition on
                |             which the state(s) have been assigned to the given activity. iConditionType
                |             could be one of "Begin Condition", "End Condition", "3D Context" or "All"
                | 
                |     Returns:
                |         oNumStates The number of 3D States that have been assigned to the given
                |         activity.
                | 
                |         Example:
                | 
                |              Dim MySelectedActivity
                |              NumStates = stateManagement.GetNumberof3DStatesInActivity(MySelectedActivity, "Begin Condition")

        :param Activity i_process:
        :param str i_condition_type:
        :rtype: int
        """
        return self.dnb_3d_state_management.GetNumberof3DStatesInActivity(i_process.com_object, i_condition_type)

    def list_3d_states_in_activity(self, i_process: Activity, i_condition_type: str, o_states: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub List3DStatesInActivity(Activity iProcess,
                | CATBSTR iConditionType,
                | CATSafeArrayVariant oStates)
                | 
                |     Returns the list of 3D states assigned to the given activity, based on the
                |     condition on which the activity has been assigned to the 3D
                |     state.
                | 
                |     Parameters:
                | 
                |         iProcess
                |             The activity whose states are to be listed. 
                |         iConditionType
                |             The type of assignment that has been made i.e., the condition on
                |             which the state(s) have been assigned to the given activity. iConditionType
                |             could be one of "Begin Condition", "End Condition", "3D Context" or "All"
                | 
                |     Returns:
                |         oStates The list of 3D States that have been assigned to the given
                |         activity.
                | 
                |         Example:
                | 
                |              Dim activitiesArray() as AnyObject
                |              Dim numActs
                |              numActs = stateManagement.GetNumberof3DStatesInActivity(MySelectedActivity)
                |              ReDim activitiesArray(numActs)
                |              stateManagement.List3DStatesInActivity MySelectedActivity, "Begin
                |              Condition",activitiesArray

        :param Activity i_process:
        :param str i_condition_type:
        :param tuple o_states:
        :rtype: None
        """
        return self.dnb_3d_state_management.List3DStatesInActivity(i_process.com_object, i_condition_type, o_states)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'list3_d_states_in_activity'
        # # vba_code = """
        # # Public Function list3_d_states_in_activity(dnb3_d_state_management)
        # #     Dim iProcess (2)
        # #     dnb3_d_state_management.List3DStatesInActivity iProcess
        # #     list3_d_states_in_activity = iProcess
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def list_all3_d_states(self) -> DNB3DStates:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ListAll3DStates() As DNB3DStates
                | 
                |     Returns the list of all 3D State objects in the process
                |     document
                | 
                |     Returns:
                |         oListStates The list of all 3D States in the current
                |         document.
                | 
                |         Example:
                | 
                |              Dim My3DStates as DNB3DStates
                |              set My3DStates = stateManagement.ListAll3DStates
                |              statesCount = My3DStates.Count

        :rtype: DNB3DStates
        """
        return DNB3DStates(self.dnb_3d_state_management.ListAll3DStates())

    def list_all_3d_states_on_object(self, i_obj: AnyObject, o_list_states: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub ListAll3DStatesOnObject(CATBaseDispatch iObj,
                | CATSafeArrayVariant oListStates)
                | 
                |     Returns the list of all 3D State objects on a given
                |     object(Resource/MA/Product..)
                | 
                |     Parameters:
                | 
                |         iObject
                |             The object(Resource/MA/Product..), whose states are to be listed.
                |             
                | 
                |     Returns:
                |         oListStates The list of all 3D States created on
                |         iObject.
                | 
                |         Example:
                | 
                |              Dim statesArray() as AnyObject
                |              Dim statesCount
                |              statesCount = stateManagement.GetNumberOf3DStatesOnObject(MySelectedProduct)
                |              Redim statesArray(statesCount)
                |              stateManagement.ListAll3DStatesOnObject(MySelectedProduct,statesArray)

        :param AnyObject i_obj:
        :param tuple o_list_states:
        :rtype: None
        """
        return self.dnb_3d_state_management.ListAll3DStatesOnObject(i_obj.com_object, o_list_states)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'list_all3_d_states_on_object'
        # # vba_code = """
        # # Public Function list_all3_d_states_on_object(dnb3_d_state_management)
        # #     Dim iObj (2)
        # #     dnb3_d_state_management.ListAll3DStatesOnObject iObj
        # #     list_all3_d_states_on_object = iObj
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'DNB3DStateManagement(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class AnalysisGeneralSettingAtt(SettingController):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         AnalysisGeneralSettingAtt
                | 
                | Interface to handle the Analysis & Simulation
                | "GeneralSetting".
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.analysis_general_setting_att = com_object

    @property
    def analysis_cache_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AnalysisCacheMode() As long
                | 
                |     Tells if Product Structure Cache Mode will be handled.

        :rtype: int
        """

        return self.analysis_general_setting_att.AnalysisCacheMode

    @analysis_cache_mode.setter
    def analysis_cache_mode(self, value: int):
        """
        :param int value:
        """

        self.analysis_general_setting_att.AnalysisCacheMode = value

    @property
    def analysis_load_mode(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AnalysisLoadMode() As long
                | 
                |     Retrieves if pointed document will be loaded.

        :rtype: int
        """

        return self.analysis_general_setting_att.AnalysisLoadMode

    @analysis_load_mode.setter
    def analysis_load_mode(self, value: int):
        """
        :param int value:
        """

        self.analysis_general_setting_att.AnalysisLoadMode = value

    @property
    def analysis_naming_auto(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AnalysisNamingAuto() As long
                | 
                |     Tells if Automatic naming will be activated.

        :rtype: int
        """

        return self.analysis_general_setting_att.AnalysisNamingAuto

    @analysis_naming_auto.setter
    def analysis_naming_auto(self, value: int):
        """
        :param int value:
        """

        self.analysis_general_setting_att.AnalysisNamingAuto = value

    @property
    def default_analysis_flag(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property DefaultAnalysisFlag() As long
                | 
                |     Retrieves if a default analysis Case will be created.

        :rtype: int
        """

        return self.analysis_general_setting_att.DefaultAnalysisFlag

    @default_analysis_flag.setter
    def default_analysis_flag(self, value: int):
        """
        :param int value:
        """

        self.analysis_general_setting_att.DefaultAnalysisFlag = value

    @property
    def default_analysis_template(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property DefaultAnalysisTemplate() As CATBSTR
                | 
                |     Retrieves the name of the default analysis Case that will be created.

        :rtype: str
        """

        return self.analysis_general_setting_att.DefaultAnalysisTemplate

    @default_analysis_template.setter
    def default_analysis_template(self, value: str):
        """
        :param str value:
        """

        self.analysis_general_setting_att.DefaultAnalysisTemplate = value

    @property
    def view_analysis_parameter(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ViewAnalysisParameter() As long
                | 
                |     Retrieves if the Parameter set is visible in the feature tree of the
                |     analysis document.

        :rtype: int
        """

        return self.analysis_general_setting_att.ViewAnalysisParameter

    @view_analysis_parameter.setter
    def view_analysis_parameter(self, value: int):
        """
        :param int value:
        """

        self.analysis_general_setting_att.ViewAnalysisParameter = value

    @property
    def view_analysis_relation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ViewAnalysisRelation() As long
                | 
                |     Retrieves if the Relation set is visible in the feature tree of the
                |     analysis document.

        :rtype: int
        """

        return self.analysis_general_setting_att.ViewAnalysisRelation

    @view_analysis_relation.setter
    def view_analysis_relation(self, value: int):
        """
        :param int value:
        """

        self.analysis_general_setting_att.ViewAnalysisRelation = value

    def get_analysis_cache_mode_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAnalysisCacheModeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the parameter.
                |     Role:Retrieves the state of the parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         AdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         oLocked
                |             Indicates if the parameter has been locked. 
                |         oModified
                |             Indicates if the parameter has been explicitly modified or remain
                |             to the administrated value. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.analysis_general_setting_att.GetAnalysisCacheModeInfo(io_admin_level, io_locked)

    def get_analysis_load_mode_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAnalysisLoadModeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the parameter.
                |     Role:Retrieves the state of the parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         AdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         oLocked
                |             Indicates if the parameter has been locked. 
                |         oModified
                |             Indicates if the parameter has been explicitly modified or remain
                |             to the administrated value. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.analysis_general_setting_att.GetAnalysisLoadModeInfo(io_admin_level, io_locked)

    def get_analysis_naming_auto_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAnalysisNamingAutoInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the parameter.
                |     Role:Retrieves the state of the parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         AdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         oLocked
                |             Indicates if the parameter has been locked. 
                |         oModified
                |             Indicates if the parameter has been explicitly modified or remain
                |             to the administrated value. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.analysis_general_setting_att.GetAnalysisNamingAutoInfo(io_admin_level, io_locked)

    def get_default_analysis_flag_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetDefaultAnalysisFlagInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the default flag.
                |     Role:Retrieves the state of the default flag in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         AdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         oLocked
                |             Indicates if the parameter has been locked. 
                |         oModified
                |             Indicates if the parameter has been explicitly modified or remain
                |             to the administrated value. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.analysis_general_setting_att.GetDefaultAnalysisFlagInfo(io_admin_level, io_locked)

    def get_default_analysis_template_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetDefaultAnalysisTemplateInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the default
                |     template.
                |     Role:Retrieves the state of the default template in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         AdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         oLocked
                |             Indicates if the parameter has been locked. 
                |         oModified
                |             Indicates if the parameter has been explicitly modified or remain
                |             to the administrated value. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.analysis_general_setting_att.GetDefaultAnalysisTemplateInfo(io_admin_level, io_locked)

    def get_view_analysis_parameter_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetViewAnalysisParameterInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the parameter.
                |     Role:Retrieves the state of the parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         AdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         oLocked
                |             Indicates if the parameter has been locked. 
                |         oModified
                |             Indicates if the parameter has been explicitly modified or remain
                |             to the administrated value. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.analysis_general_setting_att.GetViewAnalysisParameterInfo(io_admin_level, io_locked)

    def get_view_analysis_relation_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetViewAnalysisRelationInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the parameter.
                |     Role:Retrieves the state of the parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         AdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         oLocked
                |             Indicates if the parameter has been locked. 
                |         oModified
                |             Indicates if the parameter has been explicitly modified or remain
                |             to the administrated value. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.analysis_general_setting_att.GetViewAnalysisRelationInfo(io_admin_level, io_locked)

    def set_analysis_cache_mode_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAnalysisCacheModeLock(boolean iLocked)
                | 
                |     Locks or unlocks the flag.
                |     Role:Locks or unlocks the parameter if it is possible in the current
                |     administrated. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             The locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.analysis_general_setting_att.SetAnalysisCacheModeLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_analysis_cache_mode_lock'
        # # vba_code = """
        # # Public Function set_analysis_cache_mode_lock(analysis_general_setting_att)
        # #     Dim iLocked (2)
        # #     analysis_general_setting_att.SetAnalysisCacheModeLock iLocked
        # #     set_analysis_cache_mode_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_analysis_load_mode_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAnalysisLoadModeLock(boolean iLocked)
                | 
                |     Locks or unlocks the flag.
                |     Role:Locks or unlocks the parameter if it is possible in the current
                |     administrated. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             The locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.analysis_general_setting_att.SetAnalysisLoadModeLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_analysis_load_mode_lock'
        # # vba_code = """
        # # Public Function set_analysis_load_mode_lock(analysis_general_setting_att)
        # #     Dim iLocked (2)
        # #     analysis_general_setting_att.SetAnalysisLoadModeLock iLocked
        # #     set_analysis_load_mode_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_analysis_naming_auto_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAnalysisNamingAutoLock(boolean iLocked)
                | 
                |     Locks or unlocks the flag.
                |     Role:Locks or unlocks the parameter if it is possible in the current
                |     administrated. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             The locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.analysis_general_setting_att.SetAnalysisNamingAutoLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_analysis_naming_auto_lock'
        # # vba_code = """
        # # Public Function set_analysis_naming_auto_lock(analysis_general_setting_att)
        # #     Dim iLocked (2)
        # #     analysis_general_setting_att.SetAnalysisNamingAutoLock iLocked
        # #     set_analysis_naming_auto_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_default_analysis_flag_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetDefaultAnalysisFlagLock(boolean iLocked)
                | 
                |     Locks or unlocks the flag.
                |     Role:Locks or unlocks the parameter if it is possible in the current
                |     administrated. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             The locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.analysis_general_setting_att.SetDefaultAnalysisFlagLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_default_analysis_flag_lock'
        # # vba_code = """
        # # Public Function set_default_analysis_flag_lock(analysis_general_setting_att)
        # #     Dim iLocked (2)
        # #     analysis_general_setting_att.SetDefaultAnalysisFlagLock iLocked
        # #     set_default_analysis_flag_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_default_analysis_template_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetDefaultAnalysisTemplateLock(boolean iLocked)
                | 
                |     Locks or unlocks the flag.
                |     Role:Locks or unlocks the parameter if it is possible in the current
                |     administrated. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             The locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.analysis_general_setting_att.SetDefaultAnalysisTemplateLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_default_analysis_template_lock'
        # # vba_code = """
        # # Public Function set_default_analysis_template_lock(analysis_general_setting_att)
        # #     Dim iLocked (2)
        # #     analysis_general_setting_att.SetDefaultAnalysisTemplateLock iLocked
        # #     set_default_analysis_template_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_view_analysis_parameter_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetViewAnalysisParameterLock(boolean iLocked)
                | 
                |     Locks or unlocks the flag.
                |     Role:Locks or unlocks the parameter if it is possible in the current
                |     administrated. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             The locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.analysis_general_setting_att.SetViewAnalysisParameterLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_view_analysis_parameter_lock'
        # # vba_code = """
        # # Public Function set_view_analysis_parameter_lock(analysis_general_setting_att)
        # #     Dim iLocked (2)
        # #     analysis_general_setting_att.SetViewAnalysisParameterLock iLocked
        # #     set_view_analysis_parameter_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_view_analysis_relation_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetViewAnalysisRelationLock(boolean iLocked)
                | 
                |     Locks or unlocks the flag.
                |     Role:Locks or unlocks the parameter if it is possible in the current
                |     administrated. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             The locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter. 
                | 
                |     Returns:
                |         Legal values:
                |         S_OK : on Success
                |         E_FAIL: on failure

        :param bool i_locked:
        :rtype: None
        """
        return self.analysis_general_setting_att.SetViewAnalysisRelationLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_view_analysis_relation_lock'
        # # vba_code = """
        # # Public Function set_view_analysis_relation_lock(analysis_general_setting_att)
        # #     Dim iLocked (2)
        # #     analysis_general_setting_att.SetViewAnalysisRelationLock iLocked
        # #     set_view_analysis_relation_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'AnalysisGeneralSettingAtt(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.eno_cd5_interfaces.cd5_engine_v6_r2014x import CD5EngineV6R2014x
from pycatia.eno_cd5_interfaces.cd5_id import CD5ID
from pycatia.eno_cd5_interfaces.cd5_ids import CD5IDs
from pycatia.eno_cd5_interfaces.cd5_properties import CD5Properties
from pycatia.eno_cd5_interfaces.cd5_template import CD5Template
from pycatia.eno_cd5_interfaces.cd5_template_types import CD5TemplateTypes
from pycatia.in_interfaces.document import Document


class CD5EngineV6R2015(CD5EngineV6R2014x):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ENOCD5Interfaces.CD5Engine
                |                         ENOCD5Interfaces.CD5EngineV6R2014x
                |                             CD5EngineV6R2015
                | 
                | Represents the ENOVIA V6 Integration Engine, that is to say the entry point to
                | the CATIA/ENOVIA V6 Integration.
                | 
                | It allows end user to realize the various operations like ENOVIA
                | New
                | Note that all operations performed from this interface are the same as
                | operations available in the ENOVIA V6 menu in CATIA, unless most of them are
                | executed without panel.
                | 
                | Example:
                | 
                |       The following example indicates how to retrieve the ENOVIA V6 Integration
                |       Engine.
                |      
                | 
                |      Dim oCD5Engine As CD5EngineV6R2015
                |      Set oCD5Engine = CATIA.GetItem("CD5EngineV6R2015")
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.cd5_engine_v6_r2015 = com_object

    @property
    def template_types(self) -> CD5TemplateTypes:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property TemplateTypes() As CD5TemplateTypes (Read Only)
                | 
                |     Returns (gets) the list of all "Template Types".
                | 
                |     Example:
                | 
                |           The following example gets the list of Template Types. 
                |
                |          Dim oTemplateTypes As ENOIACD5TemplateTypes
                |          Set oTemplateTypes = oCD5Engine.TemplateTypes

        :rtype: CD5TemplateTypes
        """

        return CD5TemplateTypes(self.cd5_engine_v6_r2015.TemplateTypes)

    def get_id_from_physical_id(self, i_physical_id: str) -> CD5ID:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetIDFromPhysicalID(CATBSTR iPhysicalID) As CD5ID
                | 
                |     Returns CD5ID of the object for the given PhysicalID.
                | 
                |     Parameters:
                | 
                |         iPhysicalID
                |             Physical ID of the object 
                | 
                |     Returns:
                |         The created CD5ID of the object 
                |     Throws:
                | 
                |         -1697450280 : CATIA is not connected to ENOVIA V6.
                | 
                |     Example:
                | 
                |           The following example returns the ENOIACD5ID of the
                |           object:
                |
                |          iPhysicalID : "6EFB8D2E00008A445257E36100000DF7".
                |
                |          Dim ID As CD5ID
                |          Set ID = oCD5Engine.GetIDFromPhysicalID("6EFB8D2E00008A445257E36100000DF7")

        :param str i_physical_id:
        :rtype: CD5ID
        """
        return CD5ID(self.cd5_engine_v6_r2015.GetIDFromPhysicalID(i_physical_id))

    def get_i_ds_from_physical_i_ds(self, i_physical_i_ds: tuple) -> CD5IDs:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetIDsFromPhysicalIDs(CATSafeArrayVariant iPhysicalIDs) As
                | CD5IDs
                | 
                |     Returns CD5IDs of the objects for the given PhysicalIDs.
                | 
                |     Parameters:
                | 
                |         iPhysicalIDs
                |             Physical IDs of the objects 
                | 
                |     Returns:
                |         The created CD5ID array of the objects 
                |     Throws:
                | 
                |         -1697450280 : CATIA is not connected to ENOVIA V6.
                | 
                |     Example:
                | 
                |           The following example returns the ENOIACD5IDs of the
                |           object:
                |
                |             iPhysicalIDs : "6EFB8D2E00008A445257E36100000DF7,6EFB8D2E00008A445257E3610000090".
                |
                |          Dim IDs As CD5IDs
                |          Set IDs = oCD5Engine.GetIDsFromPhysicalIDs(iPhysicalIDs)

        :param tuple i_physical_i_ds:
        :rtype: CD5IDs
        """
        return CD5IDs(self.cd5_engine_v6_r2015.GetIDsFromPhysicalIDs(i_physical_i_ds))

    def get_properties(self, i_enoiacd5_id: CD5ID) -> CD5Properties:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetProperties(CD5ID iENOIACD5ID) As CD5Properties
                | 
                |     Returns a collection of all the ENOVIA V6 properties for a given Object
                |     defined by Type, Name, Revision & Version.
                | 
                |     Parameters:
                | 
                |         iENOIACD5ID
                |             The ENOIACD5ID object id representing ENOVIA V6 Object which is to
                |             be explored. 
                | 
                |     Returns:
                |         The collection of properties of the ENOVIA object passes as iENOIACD5ID
                |         
                |     Throws:
                | 
                |         -1697450280 : CATIA is not connected to ENOVIA V6.
                |         -1691273589 : Invalid object type
                |         -1857112104 : Name or Type Empty
                | 
                |     Example:
                | 
                |           The following example retrieves all the ENOVIA V6 properties from a
                |           given ENOIACD5ID.
                |
                |          Dim ObjID As CD5ID
                |          Set ObjID = oCD5Engine.GetIDFromTNRV("Versioned CATPart", "Part_Name", "A", "0")
                |          Dim oCD5Properties As CD5Properties
                |          Set oCD5Properties = oCD5Engine.GetProperties(ObjID)

        :param CD5ID i_enoiacd5_id:
        :rtype: CD5Properties
        """
        return CD5Properties(self.cd5_engine_v6_r2015.GetProperties(i_enoiacd5_id.com_object))

    def get_properties_of_document(self, i_catia_document: Document) -> CD5Properties:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetPropertiesOfDocument(Document iCATIADocument) As
                | CD5Properties
                | 
                |     Returns a collection of all the ENOVIA V6 properties for a given ENOVIA
                |     object.
                | 
                |     Parameters:
                | 
                |         iCATIADocument
                |             The document representing ENOVIA V6 Object which is to be explored.
                |
                |     Returns:
                |         The collection of properties of the ENOVIA object passes as
                |         iCATIADocument 
                |     Throws:
                | 
                |         -1697450280 : CATIA is not connected to ENOVIA V6.
                | 
                |     Example:
                | 
                |           The following example retrieves all the ENOVIA V6 properties for a
                |           given ENOVIA object.
                |
                |          Dim docCD5ID As CD5ID
                |          Set docCD5ID = oCD5Engine.GetIDFromTNR("CATProduct For Team", "MyProduct", "---")
                |          Dim objDocument As Document
                |          Set objDocument = oCD5Engine.Open(docCD5ID)
                |          Dim oCD5Properties As CD5Properties
                |          Set oCD5Properties = oCD5Engine.GetPropertiesOfDocument(objDocument)

        :param Document i_catia_document:
        :rtype: CD5Properties
        """
        return CD5Properties(self.cd5_engine_v6_r2015.GetPropertiesOfDocument(i_catia_document.com_object))

    def get_properties_of_embedded_component(
            self,
            i_catia_document: Document,
            i_embedded_component_name: str
    ) -> CD5Properties:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetPropertiesOfEmbeddedComponent(Document
                | iCATIADocument,
                | CATBSTR iEmbeddedComponentName) As CD5Properties
                | 
                |     Returns a collection of all the ENOVIA V6 properties for a given Embedded
                |     Component.
                | 
                |     Parameters:
                | 
                |         iCATIADocument
                |             The document representing ENOVIA V6 Object in which the target
                |             embedded component resides. 
                |         iEmbeddedComponentName
                |             Name of the embedded component to be explored. 
                | 
                |     Returns:
                |         The collection of properties of the embedded component passed as input
                |         
                |     Throws:
                | 
                |         -1697450280 : CATIA is not connected to ENOVIA V6.
                | 
                |     Example:
                | 
                |           The following example retrieves all the ENOVIA V6 properties for a
                |           given Embedded Component.
                |
                |          Dim docCD5ID As CD5ID
                |          Set docCD5ID = oCD5Engine.GetIDFromTNR("CATProduct For Team", "MyProduct", "---")
                |          Dim objDocument As Document
                |          Set objDocument = oCD5Engine.Open(docCD5ID)
                |          Dim oCD5Properties As CD5Properties
                |          Set oCD5Properties = oCD5Engine.GetPropertiesOfEmbeddedComponent(objDocument,
                |                                                                           "Embedded_Component_Name")

        :param Document i_catia_document:
        :param str i_embedded_component_name:
        :rtype: CD5Properties
        """
        return CD5Properties(
            self.cd5_engine_v6_r2015.GetPropertiesOfEmbeddedComponent(
                i_catia_document.com_object,
                i_embedded_component_name
            )
        )

    def new_from(self, i_cd5_template: CD5Template, i_name: str, i_type: str) -> Document:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func NewFrom(CD5Template iCD5Template,
                | CATBSTR iName,
                | CATBSTR iType) As Document
                | 
                |     Creates a new object from given template.
                | 
                |     Parameters:
                | 
                |         iCD5Template
                |             The Template object from which we want to create a new object.
                |             
                |         iName
                |             The name for the new object. 
                |         iType
                |             The ENOVIA type for the new object. 
                | 
                |     Returns:
                |         The created Document. 
                |     Throws:
                | 
                |         -1697450280 : CATIA is not connected to ENOVIA V6.
                |         -1782306828 : Template object is assigned more than one file.
                |         -1774688310 : Template object is not assigned any file.
                |         -1866082326 : File of same name as that of file attached to Template object is present on checkout directory.
                |         -1739257732 : The name for the new object contains unsupported characters.
                |         -1706631745 : An object with the same name as that of new object is already present in ENOVIA.
                |         -1844336441 : File of same name as that of new object is already present on checkout directory.
                | 
                |     Example:
                | 
                |           The following example creates a new object to be loaded in the CATIA
                |           session:
                |
                |             iCD5Template : template.
                |
                |             iName : "NewPart".
                |
                |          Dim types As Array
                |          types = oTemplateType.PossibleTypes
                |          Dim document As CATIADocument
                |          Set document = oCD5Engine.NewFrom(template, "NewPart", types(0))

        :param CD5Template i_cd5_template:
        :param str i_name:
        :param str i_type:
        :rtype: Document
        """
        return Document(self.cd5_engine_v6_r2015.NewFrom(i_cd5_template.com_object, i_name, i_type))

    def __repr__(self):
        return f'CD5EngineV6R2015(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from typing import TYPE_CHECKING

from pycatia.system_interfaces.any_object import AnyObject

if TYPE_CHECKING:
    from pycatia.behavior_interfaces.behaviors import Behaviors


class Behavior(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     Behavior
                | 
                | Represents a behavior.
                | Role: A behavior is a set of tasks performed on a technological object. It can
                | be V5 command, CAA command, VBA command, external application or behavior
                | defined into the BKT product. A behavior contains a set of variables: the
                | inputs entered by the user and the outputs produced by the behavior. This
                | interface manipulates the characteristics of a behavior: children behaviors,
                | inputs/outputs and activity.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.behavior = com_object

    @property
    def behaviors(self) -> 'Behaviors':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Behaviors() As Behaviors (Read Only)
                | 
                |     Returns the collection of children behaviors.
                | 
                |     Example:
                |         This example retrieves in BehCollection the collection of Behaviors
                |         currently managed by a Behavior Beh.
                | 
                |          Dim BehCollection As Behaviors
                |          Set BehCollection = Beh.Behaviors

        :rtype: Behaviors
        """

        from pycatia.behavior_interfaces.behaviors import Behaviors
        return Behaviors(self.behavior.Behaviors)

    def activate(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Activate()
                | 
                |     Activates a behavior.
                | 
                |     Example:
                |         This example activates a Behavior Beh.
                | 
                |          Beh.Activate

        :rtype: None
        """
        return self.behavior.Activate()

    def deactivate(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Deactivate()
                | 
                |     Deactivates a behavior.
                | 
                |     Example:
                |         This example deactivates a Behavior Beh.
                | 
                |          Beh.Deactivate

        :rtype: None
        """
        return self.behavior.Deactivate()

    def get_input(self, p_name: str) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetInput(CATBSTR pName) As AnyObject
                | 
                |     Returns the value of one available input of the behavior.
                | 
                |     Parameters:
                | 
                |         pName
                |             the name of the input 
                | 
                |     Example:
                |         This example retrieves in BehParameter the published input
                |         CATIAParameter Nb_Cylinder currently managed by a Behavior
                |         Beh.
                | 
                |          Dim BehParameter as Parameter
                |          Set BehParameter = Beh.GetInput("Nb_Cylinder")

        :param str p_name:
        :rtype: AnyObject
        """
        return AnyObject(self.behavior.GetInput(p_name))

    def get_output(self, p_name: str) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetOutput(CATBSTR pName) As AnyObject
                | 
                |     Returns the value of one available output of the behavior.
                | 
                |     Parameters:
                | 
                |         pName
                |             the name of the output 
                | 
                |     Example:
                |         This example retrieves in BehPower the published output CATIAParameter
                |         Power currently managed by a Behavior Beh.
                | 
                |          Dim BehPower as Parameter
                |          Set BehPower = Beh.GetOutput("Power")

        :param str p_name:
        :rtype: AnyObject
        """
        return AnyObject(self.behavior.GetOutput(p_name))

    def put_output(self, p_name: str, o_value: AnyObject) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub PutOutput(CATBSTR pName,
                | AnyObject oValue)
                | 
                |     Valuates an available output of the behavior. The behavior must be in
                |     operating state, otherwise it fails.
                |     It can be applicable from a CATIABehaviorVBScript Execution for
                |     instance.
                | 
                |     Parameters:
                | 
                |         pName
                |             the name of the output 
                |         oValue
                |             the value of the output 
                | 
                |     Example:
                |         This example assigns to the published CATIAParameter Power of a
                |         Behavior Beh. the value of BehPower
                | 
                |          Dim BehPower as Parameter
                |          ...
                |          Beh.PutOutput "Power", BehPower

        :param str p_name:
        :param AnyObject o_value:
        :rtype: None
        """
        return self.behavior.PutOutput(p_name, o_value.com_object)

    def test_input(self, p_name: str) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func TestInput(CATBSTR pName) As long
                | 
                |     Tests if the behavior's input is set or not.
                | 
                |     Parameters:
                | 
                |         pName
                |             the name of the input 
                | 
                |     Example:
                |         This example tests the existence of the value of the published
                |         CATIAParameter Nb_Cylinder currently managed by a Behavior
                |         Beh.
                | 
                |          if (Beh.TestInput("Nb_Cylinder"))

        :param str p_name:
        :rtype: int
        """
        return self.behavior.TestInput(p_name)

    def test_output(self, p_name: str) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func TestOutput(CATBSTR pName) As long
                | 
                |     Tests if the behavior's output is set or not.
                | 
                |     Parameters:
                | 
                |         pName
                |             the name of the output 
                | 
                |     Example:
                |         This example tests the existence of the value of the published
                |         CATIAParameter Power currently managed by a Behavior
                |         Beh.
                | 
                |          if (Beh.TestOutput("Power"))

        :param str p_name:
        :rtype: int
        """
        return self.behavior.TestOutput(p_name)

    def __repr__(self):
        return f'Behavior(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.part_interfaces.hole import Hole
from pycatia.part_interfaces.pad import Pad
from pycatia.part_interfaces.pattern import Pattern
from pycatia.system_interfaces.any_object import AnyObject


class PCBBoard(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     PCBBoard

    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.pcb_board = com_object

    @property
    def owner(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Owner() As CATBSTR
                | 
                |     Allow to get and set the attribute owner of a Panel or a Board The possible
                |     values are MCAD, ECAD, UNKNOWN
                | 
                |     Returns:
                | 
                |             The result of the method:
                |             S_OK if succeeded
                |             E_FAIL if failed

        :rtype: str
        """

        return self.pcb_board.Owner

    @owner.setter
    def owner(self, value: str):
        """
        :param str value:
        """

        self.pcb_board.Owner = value

    @property
    def part(self) -> Pad:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Part() As Pad
                | 
                |     set the pad of a Board or a component or a panel.

        :rtype: Pad
        """

        return Pad(self.pcb_board.Part)

    @part.setter
    def part(self, value: Pad):
        """
        :param Pad value:
        """

        self.pcb_board.Part = value

    def create_pcbhole(
            self,
            i_hole: Hole,
            iplating_style: str,
            i_associated_part_name: str,
            i_hole_type: str,
            i_hole_owner: str
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub create_pcbhole(Hole iHole,
                | CATBSTR iplatingStyle,
                | CATBSTR iAssociatedPartName,
                | CATBSTR iHoleType,
                | CATBSTR iHoleOwner)
                | 
                |     This method allows to add a Pcb hole to a board or a
                |     panel.
                | 
                |     Parameters:
                | 
                |         iHole
                |             This parameter represents the hole to transform in Pcb hole
                |             
                |         iplatingStyle
                |             This parameter represents the plating style of the hole. The
                |             differents values are PTH or NPTH 
                |         iAssociatedPartName
                |             This parameter represents name of the associated part to the hole.
                |             The possible values are : the name of the instance of component in which the
                |             hole is defined.
                |             BOARD if the hole is defined in the Board part
                |             PANEL If the hole is defined in the Panel part
                |             NOREFDES is the hole is defined in a non Electronic Part.
                |         iHoleType
                |             This parameter represents the function of the hole. The
                |             differents values are :
                |             PIN if the hole is associated with a component pin
                |             VIA if the hole is associated with a conductive via
                |             MTG if the hole is used for mounting purposes
                |             TOOL if the hole is used for tooling purposes Other ( User defined )
                |         iHoleOwner
                |             The parameter represents the owner of the hole.
                |             The possible values are : MCAD, ECAD, UNOWNED
                | 
                |     Returns:
                | 
                |             The result of the method:
                |             S_OK if succeeded
                |             E_FAIL if failed

        :param Hole i_hole:
        :param str iplating_style:
        :param str i_associated_part_name:
        :param str i_hole_type:
        :param str i_hole_owner:
        :rtype: None
        """
        return self.pcb_board.create_pcbhole(
            i_hole.com_object,
            iplating_style,
            i_associated_part_name,
            i_hole_type,
            i_hole_owner
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'create_pcbhole'
        # # vba_code = """
        # # Public Function create_pcbhole(pcb_board)
        # #     Dim iHole (2)
        # #     pcb_board.create_pcbhole iHole
        # #     create_pcbhole = iHole
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def create_pcbpattern(
            self,
            i_pattern: Pattern,
            iplating_style: str,
            i_associated_part_name: str,
            i_hole_type: str,
            i_hole_owner: str
    ) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub create_pcbpattern(Pattern iPattern,
                | CATBSTR iplatingStyle,
                | CATBSTR iAssociatedPartName,
                | CATBSTR iHoleType,
                | CATBSTR iHoleOwner)
                | 
                |     This method allows to add a Pcb pattern of hole to a board or a panel. If
                |     the motif hole of the pattern is pcb hole, the input value are not taken into
                |     account
                | 
                |     Parameters:
                | 
                |         iPattern
                |             This parameter represents the Pattern to transform in Pcb Pattern
                |             
                |         iplatingStyle
                |             This parameter represents the plating style of the hole. The
                |             differents values are PTH or NPTH 
                |         iAssociatedPartName
                |             This parameter represents name of the associated part to the hole.
                |             The possible values are : the name of the instance of component in which the hole is defined.
                |             BOARD if the hole is defined in the Board part
                |             PANEL If the hole is defined in the Panel part
                |             NOREFDES is the hole is defined in a non Electronic Part.
                |         iHoleType
                |             This parameter represents the function of the hole. The differents values are :
                |             PIN if the hole is associated with a component pin
                |             VIA if the hole is associated with a conductive via
                |             MTG if the hole is used for mounting purposes
                |             TOOL if the hole is used for tooling purposes Other ( User defined )
                |         iHoleOwner
                |             The parameter represents the owner of the hole.
                |             The possible values are : MCAD, ECAD, UNOWNED
                | 
                |     Returns:
                | 
                |             The result of the method:
                |             S_OK if succeeded
                |             E_FAIL if failed

        :param Pattern i_pattern:
        :param str iplating_style:
        :param str i_associated_part_name:
        :param str i_hole_type:
        :param str i_hole_owner:
        :rtype: None
        """
        return self.pcb_board.create_pcbpattern(
            i_pattern.com_object,
            iplating_style,
            i_associated_part_name,
            i_hole_type,
            i_hole_owner
        )
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'create_pcbpattern'
        # # vba_code = """
        # # Public Function create_pcbpattern(pcb_board)
        # #     Dim iPattern (2)
        # #     pcb_board.create_pcbpattern iPattern
        # #     create_pcbpattern = iPattern
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def create_zone(self, zonetype: str, i_pad: Pad) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub create_zone(CATBSTR zonetype,
                | Pad iPad)
                | 
                |     This method allows to add a constraint area to a board.
                | 
                |     Parameters:
                | 
                |         zonetype
                |             This parameter represents the type of the zone to create The
                |             differents values are ROUTE_OUTLINE, PLACE_OUTLINE, OTHER_OUTLINE, VIA_KEEPOUT,
                |             PLACE_KEEPOUT, PLACE_REGION, ROUTE_KEEPOUT 
                | 
                |     Returns:
                | 
                |             The result of the method:
                |             S_OK if succeeded
                |             E_FAIL if failed

        :param str zonetype:
        :param Pad i_pad:
        :rtype: None
        """
        return self.pcb_board.create_zone(zonetype, i_pad.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'create_zone'
        # # vba_code = """
        # # Public Function create_zone(pcb_board)
        # #     Dim zonetype (2)
        # #     pcb_board.create_zone zonetype
        # #     create_zone = zonetype
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'PCBBoard(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_sch_platform_interfaces.sch_grr_cntr import SchGRRCntr
from pycatia.cat_sch_platform_interfaces.sch_grr_route import SchGRRRoute
from pycatia.cat_sch_platform_interfaces.sch_grr_route_ellipse import SchGRRRouteEllipse
from pycatia.cat_sch_platform_interfaces.sch_grr_zone import SchGRRZone
from pycatia.cat_sch_platform_interfaces.sch_list_of_objects import SchListOfObjects
from pycatia.system_interfaces.any_object import AnyObject


class SchGRRFactory(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchGRRFactory
                | 
                | Factory to create graphical representations of schematic
                | objects.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_grr_factory = com_object

    def create_grr_cntr(self) -> SchGRRCntr:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreateGRRCntr() As SchGRRCntr
                | 
                |     Create the graphical representation of a Schematic
                |     Connector.
                | 
                |     Parameters:
                | 
                |         oGRRCntr
                |             The graphical representation of the connector 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchGRRFactory
                |          Dim objArg1 As SchGRRCntr
                |           ...
                |          Set objArg1 = objThisIntf.CreateGRRCntr

        :rtype: SchGRRCntr
        """
        return SchGRRCntr(self.sch_grr_factory.CreateGRRCntr())

    def create_grr_group(self, i_l_primitive: SchListOfObjects) -> AnyObject:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreateGRRGroup(SchListOfObjects iLPrimitive) As
                | AnyObject
                | 
                |     Create the graphical representation of a Schematic Group.
                | 
                |     Parameters:
                | 
                |         iLPrimitives
                |             A list of 2D drafting detail pointers Members are CATI2DDetail
                |             interface poiners. 
                |         oGRRGroup
                |             The graphical representation of the Group 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchGRRFactory
                |          Dim objArg1 As SchListOfObjects
                |          Dim objArg2 As AnyObject
                |           ...
                |          Set objArg2 = objThisIntf.CreateGRRGroup(objArg1)

        :param SchListOfObjects i_l_primitive:
        :rtype: AnyObject
        """
        return AnyObject(self.sch_grr_factory.CreateGRRGroup(i_l_primitive.com_object))

    def create_grr_route(self, i_l_db_line_path: tuple, o_grr_route: SchGRRRoute) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub CreateGRRRoute(CATSafeArrayVariant iLDbLinePath,
                | SchGRRRoute oGRRRoute)
                | 
                |     Create the graphical representation of a Schematic Route.
                | 
                |     Parameters:
                | 
                |         iLDbPtPath
                |             A list of X-Y coordinates of points defining the Route. 2 doubles
                |             per point. 
                |         oGRRRoute
                |             The graphical representation of the Route 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchGRRFactory
                |          Dim dbVar1(x) As CATSafeArrayVariant
                |          Dim objArg3 As SchGRRRoute
                |           ...
                |          objThisIntf.CreateGRRRoutedbVar1,objArg3

        :param tuple i_l_db_line_path:
        :param SchGRRRoute o_grr_route:
        :rtype: tuple
        """
        return self.sch_grr_factory.CreateGRRRoute(i_l_db_line_path, o_grr_route.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'create_grr_route'
        # # vba_code = """
        # # Public Function create_grr_route(sch_grr_factory)
        # #     Dim iLDbLinePath (2)
        # #     sch_grr_factory.CreateGRRRoute iLDbLinePath
        # #     create_grr_route = iLDbLinePath
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def create_grr_route_ellipse(self, i_db_xy_seed_pt: tuple, o_grr_route_ellipse: SchGRRRouteEllipse) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub CreateGRRRouteEllipse(CATSafeArrayVariant iDbXYSeedPt,
                | SchGRRRouteEllipse oGRRRouteEllipse)
                | 
                |     Create the graphical representation of a Schematic Route
                |     Ellipse.
                | 
                |     Parameters:
                | 
                |         iDbXYSeedPt
                |             X-Y coordinate of the seed point for the ellipse. If NULL, the seed
                |             point will not be set. 
                |         oGRRRouteEllipse
                |             The graphical representation of the Route Ellipse 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchGRRFactory
                |          Dim dbVar1(X) As CATSafeArrayVariant
                |          Dim objArg2 As SchGRRRouteEllipse
                |           ...
                |          objThisIntf.CreateGRRRouteEllipsedbVar1,objArg2

        :param tuple i_db_xy_seed_pt:
        :param SchGRRRouteEllipse o_grr_route_ellipse:
        :rtype: tuple
        """
        return self.sch_grr_factory.CreateGRRRouteEllipse(i_db_xy_seed_pt, o_grr_route_ellipse.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'create_grr_route_ellipse'
        # # vba_code = """
        # # Public Function create_grr_route_ellipse(sch_grr_factory)
        # #     Dim iDbXYSeedPt (2)
        # #     sch_grr_factory.CreateGRRRouteEllipse iDbXYSeedPt
        # #     create_grr_route_ellipse = iDbXYSeedPt
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def create_grr_zone(self, i_l_primitive: SchListOfObjects) -> SchGRRZone:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CreateGRRZone(SchListOfObjects iLPrimitive) As
                | SchGRRZone
                | 
                |     Create the graphical representation of a Schematic Zone.
                | 
                |     Parameters:
                | 
                |         iLPrimitives
                |             A list of 2D drafting object pointers defining the zone boundaries.
                |             
                |         oGRRZone
                |             The graphical representation of the Zone 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchGRRFactory
                |          Dim objArg1 As SchListOfObjects
                |          Dim objArg2 As SchGRRZone
                |           ...
                |          Set objArg2 = objThisIntf.CreateGRRZone(objArg1)

        :param SchListOfObjects i_l_primitive:
        :rtype: SchGRRZone
        """
        return SchGRRZone(self.sch_grr_factory.CreateGRRZone(i_l_primitive.com_object))

    def __repr__(self):
        return f'SchGRRFactory(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class SWKErgoLiftLower(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SWKErgoLiftLower
                | 
                | This interface deals the lift/lower ergonomic analysis.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.swk_ergo_lift_lower = com_object

    @property
    def coupling(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Coupling() As CATBSTR
                | 
                |     Returns or sets the coupling condition for the lift/lower
                |     analysis.
                |     The value of the parameter must be either "Good", "Fair", or
                |     "Poor".
                | 
                |     N.B.: This coupling condition must be set before
                |     attempting
                |     to retrive any output value from the study, if the input gudeline
                |     is "NIOSH1991". Failure to do so will result in invalid output
                |     values.

        :rtype: str
        """

        return self.swk_ergo_lift_lower.Coupling

    @coupling.setter
    def coupling(self, value: str):
        """
        :param str value:
        """

        self.swk_ergo_lift_lower.Coupling = value

    @property
    def duration(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Duration() As double
                | 
                |     Returns or sets the lift duration.
                |     This frequency must be expressed in hours per day, cannot be greater
                |     than 8.0 and must be specified before attempting to retrive any output
                |     value from the study.
                |     Failure to do so will result in invalid output values.

        :rtype: float
        """

        return self.swk_ergo_lift_lower.Duration

    @duration.setter
    def duration(self, value: float):
        """
        :param float value:
        """

        self.swk_ergo_lift_lower.Duration = value

    @property
    def frequency(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Frequency() As double
                | 
                |     Returns or sets the lift frequecy.
                |     This frequency must be expressed in lifts per second, and must
                |     be specified before attempting to retrive any output value from the
                |     study.
                |     Failure to do so will result in invalid output values.

        :rtype: float
        """

        return self.swk_ergo_lift_lower.Frequency

    @frequency.setter
    def frequency(self, value: float):
        """
        :param float value:
        """

        self.swk_ergo_lift_lower.Frequency = value

    @property
    def guide_line(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property GuideLine() As CATBSTR
                | 
                |     Returns or sets the guideline for the lift/lower analysis.
                |     The value of the parameter must be either "NIOSH1981", "NIOSH1991", or
                |     "SnookCiriello1991".
                | 
                |     N.B.: This guideline must be set before attempting
                |     to retrive any output value from the study, otherwise these outputs
                |     will have invalid values.

        :rtype: str
        """

        return self.swk_ergo_lift_lower.GuideLine

    @guide_line.setter
    def guide_line(self, value: str):
        """
        :param str value:
        """

        self.swk_ergo_lift_lower.GuideLine = value

    @property
    def niosh_action_limit(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NIOSH_ActionLimit() As CATBSTR (Read Only)
                | 
                |     This field is set to a valid value for the NIOSH 1981 analysis only.
                |     It is the weight below which the task could be considered reasonably
                |     safe.

        :rtype: str
        """

        return self.swk_ergo_lift_lower.NIOSH_ActionLimit

    @property
    def niosh_angle_of_asymmetry_final(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NIOSH_AngleOfAsymmetryFinal() As CATBSTR (Read
                | Only)
                | 
                |     This field is set to a valid value for the NIOSH 1991 analysis
                |     only.
                |     This value provides the angular measure of how far the object is displaced
                |     from the front (mid-sagital plane) of the worker's body at the ending of the
                |     lift, in in the current V5 units.
                |     This property gives the asymmetry angle at the destination
                |     (i.e., given the final posture of the manikin).

        :rtype: str
        """

        return self.swk_ergo_lift_lower.NIOSH_AngleOfAsymmetryFinal

    @property
    def niosh_angle_of_asymmetry_initial(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NIOSH_AngleOfAsymmetryInitial() As CATBSTR (Read
                | Only)
                | 
                |     This field is set to a valid value for the NIOSH 1991 analysis
                |     only.
                |     This value provides the angular measure of how far the object is displaced
                |     from the front (mid-sagital plane) of the worker's body at the beginning of the
                |     lift, in in the current V5 units.
                |     This property gives the asymmetry angle at the origin
                |     (i.e., given the initial posture of the manikin).

        :rtype: str
        """

        return self.swk_ergo_lift_lower.NIOSH_AngleOfAsymmetryInitial

    @property
    def niosh_asymmetric_multiplier_final(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NIOSH_AsymmetricMultiplierFinal() As CATBSTR (Read
                | Only)
                | 
                |     This field is set to a valid value for the NIOSH 1991 analysis
                |     only.
                |     This value provides the asymmetric multiplier.
                |     This property gives the asymmetric multiplier at the
                |     destination
                |     (i.e., given the final posture of the manikin).

        :rtype: str
        """

        return self.swk_ergo_lift_lower.NIOSH_AsymmetricMultiplierFinal

    @property
    def niosh_asymmetric_multiplier_initial(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NIOSH_AsymmetricMultiplierInitial() As CATBSTR (Read
                | Only)
                | 
                |     This field is set to a valid value for the NIOSH 1991 analysis
                |     only.
                |     This value provides the asymmetric multiplier.
                |     This property gives the asymmetric multiplier at the
                |     origin
                |     (i.e., given the initial posture of the manikin).

        :rtype: str
        """

        return self.swk_ergo_lift_lower.NIOSH_AsymmetricMultiplierInitial

    @property
    def niosh_coupling_multiplier_final(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NIOSH_CouplingMultiplierFinal() As CATBSTR (Read
                | Only)
                | 
                |     This field is set to a valid value for the NIOSH 1991 analysis
                |     only.
                |     This value provides the coupling multiplier bases ont hte coupling
                |     classification and vertical location of the lift (V).
                |     This property gives the coupling multiplier at the
                |     destination
                |     (i.e., given the final

        :rtype: str
        """

        return self.swk_ergo_lift_lower.NIOSH_CouplingMultiplierFinal

    @property
    def niosh_coupling_multiplier_initial(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NIOSH_CouplingMultiplierInitial() As CATBSTR (Read
                | Only)
                | 
                |     This field is set to a valid value for the NIOSH 1991 analysis
                |     only.
                |     This value provides the coupling multiplier bases ont hte coupling
                |     classification and vertical location of the lift (V).
                |     This property gives the coupling multiplier at the origin
                |     (i.e., given the initial posture of the manikin).

        :rtype: str
        """

        return self.swk_ergo_lift_lower.NIOSH_CouplingMultiplierInitial

    @property
    def niosh_distance_multiplier(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NIOSH_DistanceMultiplier() As CATBSTR (Read Only)
                | 
                |     This field is set to a valid value for the NIOSH 1991 analysis
                |     only.
                |     This value provides the distance multiplier.
                |     This property gives the distance multiplier.

        :rtype: str
        """

        return self.swk_ergo_lift_lower.NIOSH_DistanceMultiplier

    @property
    def niosh_frequency_multiplier(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NIOSH_FrequencyMultiplier() As CATBSTR (Read Only)
                | 
                |     This field is set to a valid value for the NIOSH 1991 analysis
                |     only.
                |     This value provides the frequency depending upon the average of lifts/min
                |     (F), the vertical location (V) of the hand at the origin, and the duration of
                |     continuous lifting.
                |     This property gives the frequency multiplier.

        :rtype: str
        """

        return self.swk_ergo_lift_lower.NIOSH_FrequencyMultiplier

    @property
    def niosh_horizontal_location_final(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NIOSH_HorizontalLocationFinal() As CATBSTR (Read
                | Only)
                | 
                |     This field is set to a valid value for the NIOSH 1991 analysis
                |     only.
                |     This value provides the distance of the hands from the mid-point between
                |     the ankles, in in the current V5 units.
                |     This property gives the horizontal location at the
                |     destination
                |     (i.e., given the final posture of the manikin).

        :rtype: str
        """

        return self.swk_ergo_lift_lower.NIOSH_HorizontalLocationFinal

    @property
    def niosh_horizontal_location_initial(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NIOSH_HorizontalLocationInitial() As CATBSTR (Read
                | Only)
                | 
                |     This field is set to a valid value for the NIOSH 1991 analysis
                |     only.
                |     This value provides the distance of the hands from the mid-point between
                |     the ankles, in in the current V5 units.
                |     This property gives the horizontal location at the origin
                |     (i.e., given the initial posture of the manikin).

        :rtype: str
        """

        return self.swk_ergo_lift_lower.NIOSH_HorizontalLocationInitial

    @property
    def niosh_horizontal_multiplier_final(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NIOSH_HorizontalMultiplierFinal() As CATBSTR (Read
                | Only)
                | 
                |     This field is set to a valid value for the NIOSH 1991 analysis
                |     only.
                |     This value provides the horizontal multiplier.
                |     This property gives the horizontal multiplier at the
                |     destination
                |     (i.e., given the final posture of the manikin).

        :rtype: str
        """

        return self.swk_ergo_lift_lower.NIOSH_HorizontalMultiplierFinal

    @property
    def niosh_horizontal_multiplier_initial(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NIOSH_HorizontalMultiplierInitial() As CATBSTR (Read
                | Only)
                | 
                |     This field is set to a valid value for the NIOSH 1991 analysis
                |     only.
                |     This value provides the horizontal multiplier.
                |     This property gives the horizontal multiplier at the
                |     origin
                |     (i.e., given the initial posture of the manikin).

        :rtype: str
        """

        return self.swk_ergo_lift_lower.NIOSH_HorizontalMultiplierInitial

    @property
    def niosh_li_final(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NIOSH_LIFinal() As CATBSTR (Read Only)
                | 
                |     This field is set to a valid value for the NIOSH 1991 analysis
                |     only.
                |     This value provides a relative estimate of the level of physical
                |     stress.
                |     This property gives the lifting index at the destination
                |     (i.e., given the final posture of the manikin).

        :rtype: str
        """

        return self.swk_ergo_lift_lower.NIOSH_LIFinal

    @property
    def niosh_li_initial(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NIOSH_LIInitial() As CATBSTR (Read Only)
                | 
                |     This field is set to a valid value for the NIOSH 1991 analysis
                |     only.
                |     This value provides a relative estimate of the level of physical
                |     stress.
                |     This property gives the lifting index at the origin
                |     (i.e., given the initial posture of the manikin).

        :rtype: str
        """

        return self.swk_ergo_lift_lower.NIOSH_LIInitial

    @property
    def niosh_load_constant(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NIOSH_LoadConstant() As CATBSTR (Read Only)
                | 
                |     This field is set to a valid value for the NIOSH 1991 analysis
                |     only.
                |     This value provides the load constant.
                |     This property gives the load constant at the destination
                |     (i.e., given the final posture of the manikin).

        :rtype: str
        """

        return self.swk_ergo_lift_lower.NIOSH_LoadConstant

    @property
    def niosh_maximum_perm_limit(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NIOSH_MaximumPermLimit() As CATBSTR (Read Only)
                | 
                |     This field is set to a valid value for the NIOSH 1981 analysis
                |     only.
                |     This value represents a weight limit, above which the
                |     task is considered dangerous and requires engineering controls.

        :rtype: str
        """

        return self.swk_ergo_lift_lower.NIOSH_MaximumPermLimit

    @property
    def niosh_rwl_final(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NIOSH_RWLFinal() As CATBSTR (Read Only)
                | 
                |     This field is set to a valid value for the NIOSH 1991 analysis
                |     only.
                |     It represents the weight of the load, that healthy workers
                |     could
                |     perform over a certain period of time without risk.
                |     This property gives the recommended weight at the
                |     destination
                |     (i.e., given the final posture of the manikin).

        :rtype: str
        """

        return self.swk_ergo_lift_lower.NIOSH_RWLFinal

    @property
    def niosh_rwl_initial(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NIOSH_RWLInitial() As CATBSTR (Read Only)
                | 
                |     This field is set to a valid value for the NIOSH 1991 analysis
                |     only.
                |     It represents the weight of the load that healthy workers
                |     could perform over a certain period of time without risk.
                |     This property gives the recommended weight at the origin
                |     (i.e., given the initial posture of the manikin).

        :rtype: str
        """

        return self.swk_ergo_lift_lower.NIOSH_RWLInitial

    @property
    def niosh_travel_distance(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NIOSH_TravelDistance() As CATBSTR (Read Only)
                | 
                |     This field is set to a valid value for the NIOSH 1991 analysis
                |     only.
                |     This value provides the absolute value of the difference between the
                |     vertical heights at the destination and origin of the lift, in in the current
                |     V5 units.
                |     This property gives the travel distance

        :rtype: str
        """

        return self.swk_ergo_lift_lower.NIOSH_TravelDistance

    @property
    def niosh_vertical_location_final(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NIOSH_VerticalLocationFinal() As CATBSTR (Read
                | Only)
                | 
                |     This field is set to a valid value for the NIOSH 1991 analysis
                |     only.
                |     This value provides the distance of the hands above the floor, in the
                |     current V5 units.
                |     This property gives the vertical location at the
                |     destination
                |     (i.e., given the final posture of the manikin).

        :rtype: str
        """

        return self.swk_ergo_lift_lower.NIOSH_VerticalLocationFinal

    @property
    def niosh_vertical_location_initial(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NIOSH_VerticalLocationInitial() As CATBSTR (Read
                | Only)
                | 
                |     This field is set to a valid value for the NIOSH 1991 analysis
                |     only.
                |     This value provides the distance of the hands above the floor, in in the
                |     current V5 units.
                |     This property gives the vertical location at the origin
                |     (i.e., given the initial posture of the manikin).

        :rtype: str
        """

        return self.swk_ergo_lift_lower.NIOSH_VerticalLocationInitial

    @property
    def niosh_vertical_multiplier_final(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NIOSH_VerticalMultiplierFinal() As CATBSTR (Read
                | Only)
                | 
                |     This field is set to a valid value for the NIOSH 1991 analysis
                |     only.
                |     This value provides the absolute value or deviation of V (vertical
                |     location) from an optimum height of 30 inches (75 cm).
                |     This property gives the vertical multiplier at the
                |     destination
                |     (i.e., given the final posture of the manikin).

        :rtype: str
        """

        return self.swk_ergo_lift_lower.NIOSH_VerticalMultiplierFinal

    @property
    def niosh_vertical_multiplier_initial(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property NIOSH_VerticalMultiplierInitial() As CATBSTR (Read
                | Only)
                | 
                |     This field is set to a valid value for the NIOSH 1991 analysis
                |     only.
                |     This value provides the absolute value or deviation of V (vertical
                |     location) from an optimum height of 30 inches (75 cm).
                |     This property gives the vertical multiplier at the origin
                |     (i.e., given the initial posture of the manikin).

        :rtype: str
        """

        return self.swk_ergo_lift_lower.NIOSH_VerticalMultiplierInitial

    @property
    def object_weight(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ObjectWeight() As CATBSTR
                | 
                |     Returns or sets the weight of the object being lifted.
                |     This weight must specified at least once, if the current input guideline is
                |     "NIOSH1991".
                |     Failure to do so will result in invalid output values.

        :rtype: str
        """

        return self.swk_ergo_lift_lower.ObjectWeight

    @object_weight.setter
    def object_weight(self, value: str):
        """
        :param str value:
        """

        self.swk_ergo_lift_lower.ObjectWeight = value

    @property
    def population(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Population() As double
                | 
                |     Returns or sets the percentage of the population that should be able to
                |     perform the lift/lower task safely.
                |     This property can only take the values 50.0, 75.0 and 90.0,and must be
                |     specified
                |     at least once, if the current input guideline is
                |     "NIOSH1991".
                |     Failure to do so will result in invalid output values.

        :rtype: float
        """

        return self.swk_ergo_lift_lower.Population

    @population.setter
    def population(self, value: float):
        """
        :param float value:
        """

        self.swk_ergo_lift_lower.Population = value

    @property
    def snook_maximum_weight(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Snook_MaximumWeight() As CATBSTR (Read Only)
                | 
                |     This field is set to a valid value for the Snook/Ciriello 1991 analysis
                |     only.
                |     It is the maximum acceptable weight of the load that the selected
                |     population
                |     can lift or carry with reasonable safety.

        :rtype: str
        """

        return self.swk_ergo_lift_lower.Snook_MaximumWeight

    @property
    def warning_message(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property WarningMessage() As CATBSTR (Read Only)
                | 
                |     Returns an eventual warning message generated along with the study.

        :rtype: str
        """

        return self.swk_ergo_lift_lower.WarningMessage

    def save_final_posture(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SaveFinalPosture()
                | 
                |     Saves the current posture of the mankin as the final posture for the
                |     lift/lower analysis.

        :rtype: None
        """
        return self.swk_ergo_lift_lower.SaveFinalPosture()

    def save_initial_posture(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SaveInitialPosture()
                | 
                |     Saves the current posture of the mankin as the initial posture for the
                |     lift/lower analysis.

        :rtype: None
        """
        return self.swk_ergo_lift_lower.SaveInitialPosture()

    def __repr__(self):
        return f'SWKErgoLiftLower(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.dmaps_interfaces.item import Item
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class Items(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     Items
                | 
                | The collection of items related to the current activity.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=Item)
        self.items_ = com_object

    def add(self, i_product: Item) -> Item:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Add(Item iProduct) As Item
                | 
                |     This method adds the specified item in the current list
                | 
                |     Parameters:
                | 
                |         iItem
                |             The item to add 
                | 
                |     Returns:
                |         oitem The item

        :param Item i_product:
        :rtype: Item
        """
        return Item(self.items_.Add(i_product.com_object))

    def add_by_assignment_type(self, i_item: Item, i_assignment_type: int) -> Item:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddByAssignmentType(Item iItem,
                | ItemAssignmentType iAssignmentType) As Item
                | 
                |     This method Assigns the specified item with the specified assignment
                |     type
                | 
                |     Parameters:
                | 
                |         iItem
                |             The item to be assigned 
                |         iAssignmentType
                |             Type of the Assignment (Item to the Process) 
                | 
                |     Returns:
                |         oitem The item

        :param Item i_item:
        :param int i_assignment_type: enum item_assignment_type
        :rtype: Item
        """
        return Item(self.items_.AddByAssignmentType(i_item.com_object, i_assignment_type))

    def count_by_assignment_type(self, i_assignment_type: int) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func CountByAssignmentType(ItemAssignmentType iAssignmentType) As
                | long
                | 
                |     This method returns the Number of items that assocated with the activity
                |     with given Assignment Type.
                | 
                |     Parameters:
                | 
                |         iAssignmentType
                |             Type of the Assignment between items & the activity
                |             
                | 
                |     Returns:
                |         oNbItems No. of Items that are assigned to the activity with the given
                |         assignment type.

        :param int i_assignment_type: enum item_assignment_type
        :rtype: int
        """
        return self.items_.CountByAssignmentType(i_assignment_type)

    def item(self, i_index: cat_variant) -> Item:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As Item
                | 
                |     This method returns the idl object Item for the specified item
                |     identifier.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The item identifier 
                | 
                |     Returns:
                |         oItem The idl item

        :param cat_variant i_index:
        :rtype: Item
        """
        return Item(self.items_.Item(i_index))

    def item_by_assignment_type(self, i_index: cat_variant, i_assignment_type: int) -> Item:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ItemByAssignmentType(CATVariant iIndex,
                | ItemAssignmentType iAssignmentType) As Item
                | 
                |     This method returns the item assocated with the activity with given
                |     Assignment Type.
                | 
                |     Parameters:
                | 
                |         iAssignmentType
                |             Type of the Assignment between item & the activity
                |             
                | 
                |     Returns:
                |         oItem idl item to be returned

        :param cat_variant i_index:
        :param int i_assignment_type: enum item_assignment_type
        :rtype: Item
        """
        return Item(self.items_.ItemByAssignmentType(i_index, i_assignment_type))

    def remove_by_assignment_type(self, i_item: Item, i_assignment_type: int) -> Item:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func RemoveByAssignmentType(Item iItem,
                | ItemAssignmentType iAssignmentType) As Item
                | 
                |     This method used to unassign the specified item (with the given assignment
                |     type)
                | 
                |     Parameters:
                | 
                |         iItem
                |             The item to be Unassigned 
                |         iAssignmentType
                |             Type of the Assignment (Item to the Process) to be removed
                |             
                | 
                |     Returns:
                |         oitem The item

        :param Item i_item:
        :param int i_assignment_type: enum item_assignment_type
        :rtype: Item
        """
        return Item(self.items_.RemoveByAssignmentType(i_item.com_object, i_assignment_type))

    def __repr__(self):
        return f'Items(name="{self.name}")'
